<?php
class Docente {
  private $cod;
  private $nome;
  private $dataNasc;
  private $dataIngresso;
  private $coordenador;
  private $pontuacao;

  function __construct($cod, $nome, $dataNasc, $dataIngresso, $coordenador) {
    $this->cod = $cod;
    $this->nome = $nome;
    $this->dataNasc = $dataNasc;
    $this->dataIngresso = $dataIngresso;
    $this->coordenador = $coordenador;
    $this->pontuacao = 0;
  }

  //calcula pontuacão do docente
  public function calculaPontuacao($publicp, $publicc, $veiculos, $regras, $anoRecred) {
    $this->pontuacao = 0;
    $valor = 0;
    $numAnos = $regras->getAnos();
    //somando a pontuação em publicações em periódicos
    foreach ($publicp as $pbp) {
      if ($pbp->ehAutor($this->cod)) {
        $ano = $pbp->getAno();
        if (($ano >= ($anoRecred - $numAnos)) && ($ano < $anoRecred)) {
          $qualificacao = $pbp->getVeiculo()->getQualificacao($ano);
          $valor = $qualificacao->getQualis()->getPontuacao();
          $this->pontuacao += ($valor * $regras->getFatorMult());
        }
      }
    }
    //somando a pontuação em publicações em conferencias
    foreach ($publicc as $pbc) {
      if ($pbc->ehAutor($this->cod)) {
        $ano = $pbc->getAno();
        if (($ano >= ($anoRecred - $numAnos)) && ($ano < $anoRecred)) {
          $qualificacao = $pbc->getVeiculo()->getQualificacao($ano);
          $valor = $qualificacao->getQualis()->getPontuacao();
          $this->pontuacao += $valor;
        }
      }
    }
  }

  //Retorna se o docente é recredenciado, junto com o tipo de recredenciamento
  public function ehRecredenciado($regras, $ano) {
    $hoje = new DateTime($ano . "-01-01");
    if ($this->coordenador)
      return "Coordenador";
    else if (intval($hoje->format('Y')) - intval($this->dataIngresso->format('Y')) < 3)
      return "PPJ";
    else if (intval($hoje->format('Y')) - intval($this->dataNasc->format('Y')) >= 60)
      return "PPS";
    else if ($this->pontuacao > $regras->getPontMin())
      return "Sim";
    else
      return "Não";
  }

  public function toString() {
    return $this->nome . ";" . number_format($this->pontuacao, 1, ',', '') .	";";
  }

  // getters
  public function getCod() {
    return $this->cod;
  }

  public function getNome() {
    return $this->nome;
  }

  public function getPontuacao() {
    return $this->pontuacao;
  }
}
?>
